%% graph_plotting
% Generates the figures for this best-fit simulation

set(0,'DefaultAxesFontSize',15);

%% Empirical data from the Department of Health

% Empirical data of RA daily hospital admissions
hFig = new_figure;
for t1 = 1:1:num_classes
    plot(squeeze(actual_daily_RA_hosp(t1,:)),'LineWidth',2);
    hold on;
end
ylabel({'7-day rolling average of empirical daily' 'new hospital admissions by age'});
legend('0-19','20-39','40-59','60-79','80+','Location','NorthWest');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname = sprintf('../%d/covid_ni_model_%d_empirical_new_RA_hosp_by_age',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);

% total empirical data of RA daily hospital admissions
hFig = new_figure;
plot(actual_daily_RA_hosp_full_total,'LineWidth',2);
ylabel({'7-day rolling average of empirical daily' 'new hospital admissions in total'});
format_axes(num_beta_periods,beta_period_begin,num_days)
printname = sprintf('../%d/covid_ni_model_%d_empirical_new_RA_hosp_total',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);

% Load the empirical data of total hospital inpatients, ICU
% inpatients, cumulative deaths
actual_hosp = readmatrix('../Data/empirical_inpatients_PREPARED.csv');
actual_total_ICU = readmatrix('../Data/empirical_ICU_PREPARED.csv');
actual_cumulativedeaths = readmatrix('../Data/empirical_cumulativedeaths_PREPARED.csv');

hFig = new_figure;
plot(actual_hosp(:,6),'LineWidth',2);
hold on;
plot(actual_total_ICU(:),'LineWidth',2);
hold on;
plot(actual_cumulativedeaths(:,6),'LineWidth',2);
box on;
ylabel('Empirical total');
ylim([0 2500]);
legend('Hospital occupancy','ICU occupancy','Cumulative deaths','Location','NorthWest');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname = sprintf('../%d/covid_ni_model_%d_empirical_in_hosp_ICU_deaths_total',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);


% Empirical total new deaths
actual_newdeaths = readmatrix('../Data/empirical_newdeaths_PREPARED.csv');

hFig = new_figure;
plot(actual_newdeaths(:,6),'LineWidth',2);
ylabel('Empirical total daily new deaths');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname = sprintf('../%d/covid_ni_model_%d_empirical_new_deaths_total',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);


% Empirical new deaths by age
hFig = new_figure;
for t1 = 1:1:num_classes
    plot(actual_newdeaths(:,t1),'LineWidth',2);
    hold on;
end
ylabel('Empirical daily new deaths by age');
legend('0-19','20-39','40-59','60-79','80+','Location','NorthWest');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname = sprintf('../%d/covid_ni_model_%d_empirical_new_deaths_by_age',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);


% Empirical total cumulative deaths
hFig = new_figure;
plot(actual_cumulativedeaths(:,6),'LineWidth',2);
ylabel('Empirical total cumulative deaths');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname = sprintf('../%d/covid_ni_model_%d_empirical_in_deaths_total',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);


% Empirical cumulative deaths by age
hFig = new_figure;
for t1 = 1:1:num_classes
    plot(actual_cumulativedeaths(:,t1),'LineWidth',2);
    hold on;
end
ylabel('Empirical cumulative deaths by age');
legend('0-19','20-39','40-59','60-79','80+','Location','NorthWest');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname = sprintf('../%d/covid_ni_model_%d_empirical_in_deaths_by_age',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);

% Empirical total inpatients
hFig = new_figure;
plot(actual_hosp(:,6),'LineWidth',2);
ylabel('Empirical total inpatients');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname = sprintf('../%d/covid_ni_model_%d_empirical_in_hosp_total',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);

% Empirical inpatients by age
hFig = new_figure;
for t1 = 1:1:num_classes
    plot(actual_hosp(:,t1),'LineWidth',2);
    hold on;
end
ylabel('Empirical daily inpatients by age');
legend('0-19','20-39','40-59','60-79','80+','Location','NorthWest');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname = sprintf('../%d/covid_ni_model_%d_empirical_inpatients_by_age',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);


%% Fitted and projected values from the best fit simulation   

% Plot the final best output of projected hospitalisations
hFig = new_figure;
for t1 = 1:1:num_classes
    plot(squeeze(best_projected_hosp(t1,:)),'LineWidth',2);
    hold on;
end
ylabel('Daily new hospital admissions');
legend('0-19','20-39','40-59','60-79','80+','Location','NorthWest');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname = sprintf('../%d/covid_ni_model_%d_proj_new_hosp_by_age',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);

% Plot the final best output of rolling average of projected
% hospitalisations
hFig = new_figure;
for t1 = 1:1:num_classes
    plot(squeeze(best_roll_projected_hosp(t1,:)),'LineWidth',2);
    hold on;
end
ylabel({'7-day rolling average of projected daily' 'new hospital admissions by age'});
legend('0-19','20-39','40-59','60-79','80+','Location','NorthWest');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname = sprintf('../%d/covid_ni_model_%d_FIT_proj_new_RA_hosp_by_age',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);

% Plot the final best output of projected icu
hFig = new_figure;
for t1 = 1:1:num_classes
    plot(squeeze(best_projected_icu(t1,:)),'LineWidth',2);
    hold on;
end
ylabel('Daily new ICU admissions');
legend('0-19','20-39','40-59','60-79','80+','Location','NorthWest');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname = sprintf('../%d/covid_ni_model_%d_proj_new_icu_by_age',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);

% Plot the final best output of projected deaths
hFig = new_figure;
for t1 = 1:1:num_classes
    plot(squeeze(best_projected_deaths(t1,:)),'LineWidth',2);
    hold on;
end
ylabel('Daily new deaths');
legend('0-19','20-39','40-59','60-79','80+','Location','NorthWest');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname = sprintf('../%d/covid_ni_model_%d_proj_new_deaths_by_age',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);


% Plot the time-series of the disease, by class
class_names = {'0-19','20-39','40-59','60-79','80+'};
for t1 = 1:1:num_classes
    hFig = new_figure;
    plot(squeeze(best_susceptible(t1,:)),'LineWidth',2);
    hold on;
    plot(squeeze(best_exposed(t1,:)),'LineWidth',2);
    hold on;
    plot(squeeze(all_infected(t1,:)),'LineWidth',2);
    hold on;
    plot(squeeze(all_recovered(t1,:)),'LineWidth',2);
    hold on;
    plot(squeeze(best_dead(t1,:)),'LineWidth',2);
    ylabel_name = sprintf('Time series for age class %s',class_names{t1});
    ylabel(ylabel_name);
    legend('Susceptible','Exposed','Infected','Recovered','Deceased','Location','SouthWest');
    format_axes(num_beta_periods,beta_period_begin,num_days)
    printname = sprintf('../%d/covid_ni_model_%d_proj_ageclass_%d',version,version,t1);
    print(printname,'-dpng','-r400','-painters');
    close(hFig);
end


% Plot the time-series of the disease, by compartment
compartment_array = {best_susceptible,best_exposed,best_infectious,best_recovered};
compartment_name = {'Susceptible','Exposed','Infectious subclinical','Infectious clinical','Recovered subclinical','Recovered clinical'};
for t1 = 1:1:6
    hFig = new_figure;
    if (t1<3)
        data_matrix1 = compartment_array{t1};
        data_matrix = squeeze(data_matrix1(:,:));
    else
        data_matrix1 = compartment_array{1.5+(t1-mod(t1+1,2))/2}; % 3, 3, 4, 4
        data_matrix = squeeze(data_matrix1(:,1+mod(t1+1,2),:));
    end
    for t2 = 1:1:num_classes
        plot(data_matrix(t2,:),'LineWidth',2);
        hold on;
    end
    clear data_matrix data_matrix1;
    ylabel_1 = 'Time series for';
    ylabel_2 = sprintf('%s compartment',compartment_name{t1});
    ylabel_name = {ylabel_1,ylabel_2};
    ylabel(ylabel_name);
    legend('0-19','20-39','40-59','60-79','80+','Location','NorthWest');
    format_axes(num_beta_periods,beta_period_begin,num_days)
    printname = sprintf('../%d/covid_ni_model_%d_proj_compartment_%d',version,version,t1);
    print(printname,'-dpng','-r400','-painters');
    close(hFig);
end

% Plot the projected number in hospital by age-class
hFig = new_figure;
for t1=1:1:num_classes
    plot(squeeze(all_hospitalised(t1,:)),'LineWidth',2);
    hold on;
end
ylabel('Projected hospital occupancy by age class');
legend('0-19','20-39','40-59','60-79','80+','Location','NorthWest');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname=sprintf('../%d/covid_ni_model_%d_proj_in_hosp_by_age',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);

% Plot the projected number in ICU by age-class
hFig = new_figure;
for t1=1:1:num_classes
    plot(squeeze(best_hospitalised(t1,2,:)),'LineWidth',2);
    hold on;
end
ylabel('Projected ICU occupancy by age class');
legend('0-19','20-39','40-59','60-79','80+','Location','NorthWest');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname=sprintf('../%d/covid_ni_model_%d_proj_in_icu_by_age',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);

% Plot the projected cumulative deaths by age-class
hFig = new_figure;
for t1=1:1:num_classes
    plot(squeeze(best_dead(t1,:)),'LineWidth',2);
    hold on;
end
ylabel('Projected cumulative deaths by age class');
legend('0-19','20-39','40-59','60-79','80+','Location','NorthWest');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname=sprintf('../%d/covid_ni_model_%d_proj_in_deaths_by_age',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% TOTALS FOR THE WHOLE POPULATION

% Plot the projected daily new admissions to hospital in total
hFig = new_figure;
plot(projected_hosp_full_total,'LineWidth',2);
ylabel({'Projected daily new', 'hospital admissions in total'});
format_axes(num_beta_periods,beta_period_begin,num_days)
printname=sprintf('../%d/covid_ni_model_%d_proj_new_hosp_total',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);

% Plot the projected daily new admissions to ICU in total
hFig = new_figure;
plot(projected_icu_full_total,'LineWidth',2);
ylabel({'Projected daily new', 'ICU admissions in total'});
format_axes(num_beta_periods,beta_period_begin,num_days)
printname=sprintf('../%d/covid_ni_model_%d_proj_new_icu_total',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);

% Plot the projected daily new deaths in total
hFig = new_figure;
plot(projected_deaths_full_total,'LineWidth',2);
ylabel('Projected daily new deaths in total');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname=sprintf('../%d/covid_ni_model_%d_proj_new_deaths_total',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);

% Plot the projected number in hospital in total
hFig = new_figure;
plot(all_hospitalised_full_total,'LineWidth',2);
ylabel('Projected hospital occupancy in total');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname=sprintf('../%d/covid_ni_model_%d_proj_in_hosp_total',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);

% Plot the projected number in ICU in total
hFig = new_figure;
plot(squeeze(hospitalised_full_total(2,:)),'LineWidth',2);
ylabel('Projected ICU occupancy in total');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname=sprintf('../%d/covid_ni_model_%d_proj_in_icu_total',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);

% Plot the projected cumulative deaths in total
hFig = new_figure;
plot(dead_full_total,'LineWidth',2);
ylabel('Projected cumulative deaths in total');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname=sprintf('../%d/covid_ni_model_%d_proj_in_deaths_total',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);


% Plot the combination of projected cumulative deaths, people in ICU
% and people in hospital, in total
hFig = new_figure;
plot(all_hospitalised_full_total,'LineWidth',2);
hold on;
plot(squeeze(hospitalised_full_total(2,:)),'LineWidth',2);
hold on;
plot(dead_full_total,'LineWidth',2);
ylabel('Projected total');
legend('Hospital occupancy','ICU occupancy','Cumulative deaths','Location','NorthWest');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname=sprintf('../%d/covid_ni_model_%d_proj_in_hosp_ICU_deaths_total',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);


% Plot the time-series of the disease in total
hFig = new_figure;
plot(susceptible_full_total,'LineWidth',2);
hold on;
plot(exposed_full_total,'LineWidth',2);
hold on;
plot(all_infected_full_total,'LineWidth',2);
hold on;
plot(all_recovered_full_total,'LineWidth',2);
hold on;
plot(dead_full_total,'LineWidth',2);
ylabel('Projections');
legend('Susceptible','Exposed','Infected','Recovered','Deceased','Location','NorthWest');
format_axes(num_beta_periods,beta_period_begin,num_days)
printname=sprintf('../%d/covid_ni_model_%d_proj_compartments_total',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);

% Cumulative fraction of population who have contracted COVID-19
cumulative_propagation = 1.0-susceptible_full_total/population;
hFig = new_figure;
plot(cumulative_propagation,'LineWidth',2);
ylabel({'Fraction of population who' 'have contracted COVID-19'});
format_axes(num_beta_periods,beta_period_begin,num_days)
printname=sprintf('../%d/covid_ni_model_%d_proj_fraction_contracted_total',version,version);
print(printname,'-dpng','-r400','-painters');
close(hFig);


%% Begin figure subroutine:
function [hFig] = new_figure
    hFig = figure('visible','on');
    clf(hFig);
    hold off;
end

%% Formatting figure axes subroutine:
function format_axes(num_beta_periods,beta_period_begin,num_days)
    dates_ticks = [1 60 120 180 240 300 360]; 
    dates_tickslabels = {'January 2020','March 2020','May 2020','July 2020',...
        'September 2020','November 2020','January 2021'};

    box on; 
    for n = 2:1:num_beta_periods
        xline(beta_period_begin(n),'HandleVisibility','off');
    end 
    xlim([0 num_days]);
    xlabel('Date');
    xticks(dates_ticks);
    xticklabels(dates_tickslabels);
    xtickangle(45);
    YLAB=get(gca,'yticklabels');
    YTIC=get(gca,'ytick');
    YLIM=get(gca,'ylim');
    yyaxis right;
    set(gca,'ytick',YTIC,'yticklabels',YLAB,'ylim',YLIM,'ycolor','black');
end

