%% iterate
% Updates the compartments of each age-class for one time-step

temp_susceptible = zeros(num_classes,1);
temp_exposed = zeros(num_classes,1);
temp_infectious = zeros(num_classes,2);
temp_hospitalised = zeros(num_classes,2);
temp_NEW_hospitalised = zeros(num_classes,1);
temp_NEW_icu = zeros(num_classes,1);
temp_recovered = zeros(num_classes,2);
temp_dead = zeros(num_classes,1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Calculate the potential change for each compartment
for n1 = 1:1:num_classes

    % Potential new infections first:
    temp_change = 0.0;

    for n2 = 1:1:num_classes

        % Add the change to class n1 due to infection by class n2
        temp_change = temp_change + beta*contact(n2,n1)*(infectious(n2,1,i0-1) + clinical_beta_scale*infectious(n2,2,i0-1));

    end
    % Calculate maximum total change in susceptibles
    temp_change_total = min(susceptible(n1,i0-1), euler_delta*susceptibility_delta(n1)...
        *temp_change*susceptible(n1,i0-1)*class_population(n1).^(-1.0));


    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % Use this to determine change in susceptible and exposed compartments:
    temp_susceptible(n1) = -temp_change_total;
    temp_exposed(n1) = temp_change_total - euler_delta*sigma*exposed(n1,i0-1);

    % Infectious (not hospitalised)
    temp_infectious(n1,1) = euler_delta*(sigma*exposed_to_sub(n1)*exposed(n1,i0-1)...
        - gamma(1)*infectious(n1,1,i0-1));
    temp_infectious(n1,2) = euler_delta*(gamma(1)*sub_to_clinical(n1)*infectious(n1,1,i0-1)...
        + sigma*exposed_to_clinical(n1)*exposed(n1,i0-1) - gamma(2)*infectious(n1,2,i0-1));

    % Hospitalised (not ICU)
    temp_hospitalised(n1,1) = euler_delta*(age_hosp_profile(n1)*gamma(2)...
        *infectious(n1,2,i0-1) - rate_leave_hosp*hospitalised(n1,1,i0-1));

    % Specifically NEW ADMISSIONS (not "change" as this is the net change 
    % and thus includes those who leave) for fitting the rolling average:
    temp_NEW_hospitalised(n1) = euler_delta*age_hosp_profile(n1)*gamma(2)*infectious(n1,2,i0-1);

    % ICU
    temp_hospitalised(n1,2) = euler_delta*( age_icu_profile(n1)*rate_leave_hosp*hospitalised(n1,1,i0-1)...
        - rate_leave_icu*hospitalised(n1,2,i0-1));
    temp_NEW_icu(n1) = euler_delta*age_icu_profile(n1)*rate_leave_hosp*hospitalised(n1,1,i0-1);

    % Deceased
    temp_dead(n1) = euler_delta*( age_death_ward_profile(n1)*rate_leave_hosp*hospitalised(n1,1,i0-1) + age_death_icu_profile(n1)*rate_leave_icu*hospitalised(n1,2,i0-1));

    % Recovered
    % From a subclinical infection:
    temp_recovered(n1,1) = euler_delta*sub_to_recovery(n1)*gamma(1)*infectious(n1,1,i0-1);
    % From a clinical infection (or hospital, or ICU):
    temp_recovered(n1,2) = euler_delta*((1.0-age_hosp_profile(n1))*gamma(2)*infectious(n1,2,i0-1) + ...
        (1.0-(age_death_ward_profile(n1)+age_icu_profile(n1)))*rate_leave_hosp*hospitalised(n1,1,i0-1) + ...
        (1.0-age_death_icu_profile(n1))*rate_leave_icu*hospitalised(n1,2,i0-1));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Now actually update the values of the compartments with these changes,
% and set the compartment to zero if below the minimum value epsilon:
for n3 = 1:1:num_classes

    % Update all according to the Euler method
    susceptible(n3,i0) = max(0.0, susceptible(n3,i0-1) + temp_susceptible(n3));
    if (susceptible(n3,i0) < epsilon_min)
        susceptible(n3,i0) =0.0;
    end

    exposed(n3,i0) = max(0.0, exposed(n3,i0-1) + temp_exposed(n3));
    if (exposed(n3,i0) < epsilon_min)
        exposed(n3,i0) = 0.0;
    end

    for t3 = 1:1:2 % two levels of severity

        infectious(n3,t3,i0) = max(0.0, infectious(n3,t3,i0-1) + temp_infectious(n3,t3));
        if (infectious(n3,t3,i0) < epsilon_min)
            infectious(n3,t3,i0) = 0.0;
        end

        hospitalised(n3,t3,i0) = max(0.0, hospitalised(n3,t3,i0-1) + temp_hospitalised(n3,t3));
        if (hospitalised(n3,t3,i0) < epsilon_min)
            hospitalised(n3,t3,i0) = 0.0;
        end

        recovered(n3,t3,i0) = max(0.0, recovered(n3,t3,i0-1) + temp_recovered(n3,t3));
        if (recovered(n3,t3,i0) < epsilon_min)
            recovered(n3,t3,i0) = 0.0;
        end

    end

    dead(n3,i0) = max(0.0, dead(n3,i0-1) + temp_dead(n3));
    if (dead(n3,i0) < epsilon_min)
        dead(n3,i0) = 0.0;
    end

end



